@@ -27,5 +27,5 @@ class TestExtension:
         m = MagicMock()
 
         m.web_app.settings = {}
-        m.web_app.settings['base_url'] = '/test'
+        m.web_app.settings["base_url"] = "/test"
         load_jupyter_server_extension(m)
